=========
Changelog
=========

All notable changes to this project will be documented in this file.

The format is based on `Keep a Changelog <https://keepachangelog.com>`_.

0.1.3
------

Added
+++++
* Added ``hspace`` as option to ``Targets.plot``.

0.1.2
-----

Added
+++++
* Added ``select_target_names`` option to ``Targets``.

0.1.1
-----

Fixed
+++++
* Fixed DataFrame querying bug in ``./alignparse/ccs.py``

0.1.0
-----
Initial release

